#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const index_1 = require("./index");
const path = __importStar(require("path"));
const fs = __importStar(require("fs"));
commander_1.program
    .name('hd-css-to-variable')
    .description('将CSS/SCSS文件中的指定属性值提取为全局CSS变量')
    .version('1.0.5')
    .addHelpText('after', `
示例:
  $ hd-css-to-variable build -d ./src
  $ hd-css-to-variable extract -d ./src -p color,background-color
  $ hd-css-to-variable extract -d ./src -p color,background-image --prefix theme --assets-output true

命令:
  build                使用预设参数执行变量提取
  extract              使用自定义参数执行变量提取

选项:
  -d, --directory      要扫描的目录路径
  -p, --properties     要提取的CSS属性列表，用逗号分隔
  --prefix             变量名前缀 (默认: "var")
  --output            输出的变量文件名 (默认: "variables.css")
  --pattern           文件匹配模式 (默认: "**/*.{css,scss}")
  --assets-output     是否输出图片资源的base64变量 (默认: false)
  -h, --help          显示帮助信息
  -v, --version       显示版本号
`);
commander_1.program
    .command('build')
    .description('使用预设参数执行变量提取')
    .option('-d, --directory <path>', '要扫描的目录路径', './src')
    .action((options) => {
    const directory = path.resolve(options.directory);
    // 检查目录是否存在
    if (!fs.existsSync(directory)) {
        console.error('❌ 错误：指定的目录不存在！');
        process.exit(1);
    }
    const cssToVariable = new index_1.CssToVariable({
        directory,
        properties: ['color', 'background-color', 'background-image', 'background'],
        prefix: ''
    });
    cssToVariable.extract()
        .then(() => {
        console.log('✨ CSS变量提取完成！');
    })
        .catch((error) => {
        console.error('❌ 发生错误：', error);
        process.exit(1);
    });
});
commander_1.program
    .command('extract')
    .description('使用自定义参数执行变量提取')
    .requiredOption('-d, --directory <path>', '要扫描的目录路径')
    .requiredOption('-p, --properties <items>', '要提取的CSS属性列表，用逗号分隔')
    .option('--prefix <string>', '变量名前缀', '')
    .option('--output <filename>', '输出的变量文件名', 'variables.css')
    .option('--pattern <pattern>', '文件匹配模式', '**/*.{css,scss}')
    .option('--assets-output <boolean>', '是否输出图片资源的base64变量', false)
    .option('--split-by-folder <boolean>', '是否按文件夹拆分变量文件', false) // 添加新参数
    .action((options) => {
    const directory = path.resolve(options.directory);
    // 检查目录是否存在
    if (!fs.existsSync(directory)) {
        console.error('❌ 错误：指定的目录不存在！');
        process.exit(1);
    }
    const cssToVariable = new index_1.CssToVariable({
        directory,
        properties: options.properties.split(','),
        prefix: options.prefix,
        outputFile: options.output,
        pattern: options.pattern,
        assetsOutput: options.assetsOutput === 'true', // 将字符串转换为布尔值传递给参数
        splitByFolder: options.splitByFolder === 'true' // 添加splitByFolder参数
    });
    cssToVariable.extract()
        .then(() => {
        console.log('✨ CSS变量提取完成！');
    })
        .catch((error) => {
        console.error('❌ 发生错误：', error);
        process.exit(1);
    });
});
commander_1.program.parse();
